@@ -113,6 +113,7 @@ class Decoder:
         return(result)
 
     def _decode_wind(self, wind):
+        unit = ""
         result = ""
 
         if wind["direction"] == "000":
@@ -122,10 +123,18 @@ class Decoder:
         else:
             result += "from %s degrees" % wind["direction"]
 
-        result += " at %s knots" % wind["speed"]
+        if wind["unit"] == "KT":
+            unit = "knots"
+        elif wind["unit"] == "MPS":
+            unit = "meters per second"
+        else:
+            # Unlikely, but who knows
+            unit = "(unknown unit)"
+
+        result += " at %s %s" % (wind["speed"], unit)
 
         if wind["gust"]:
-            result += " gusting to %s knots" % wind["gust"]
+            result += " gusting to %s %s" % (wind["gust"], unit)
 
         return(result)
 
@@ -154,6 +163,15 @@ class Decoder:
             if layer["layer"] == "SKC" or layer["layer"] == "CLR":
                 return "sky clear"
 
+            if layer["layer"] == "NSC":
+                return "no significant cloud"
+
+            if layer["layer"] == "CAVOK":
+                return "ceiling and visibility are OK"
+
+            if layer["layer"] == "CAVU":
+                return "ceiling and visibility unrestricted"
+
             if layer["layer"] == "SCT":
                 layer_type = "scattered"
             elif layer["layer"] == "BKN":
